<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
  xmlns:xlink="http://www.w3.org/1999/xlink"
  xmlns:d="http://docbook.org/ns/docbook"
  xmlns="http://www.w3.org/1999/xhtml">
  
  <xsl:import href="../../docbook-xsl/xhtml/chunk.xsl"/>
  <xsl:import href="../../docbook-xsl/xhtml/highlight.xsl"/>
  <xsl:import href="../../docbook-xsl/webhelp/xsl/webhelp-common.xsl"/>
  <xsl:import href="../../docbook-xsl/webhelp/xsl/titlepage.templates.xsl"/>
  
  <xsl:import href="../Common/common.xsl"/>
  <xsl:import href="../../Preprocess/Xsl/slideReference.xsl"/>
  
  <xsl:variable name="topicLookup" select="document('topics.tid.xml', .)"/>
  
  <xsl:template match="/">        
    <xsl:apply-templates select="
      (//d:chapter | //d:section | //d:appendix) [contains(@annotations, 'slide') or 
      descendant::*[contains(@annotations, 'slide')]]"
      mode = "slideUnit"/>    
  </xsl:template>
  
  <xsl:template name="createBreadcrumbHierarchy">
    <xsl:param name="nodes"/>
    <xsl:param name="currentPosition"/>
    <ul>
      <li style="list-style-type: none;">
        
        <xsl:if test="not($currentPosition = 1)">
          <xsl:text>➟ </xsl:text>
        </xsl:if>
        
        <xsl:apply-templates select="$nodes[$currentPosition]/d:title/text()|$nodes[$currentPosition]/d:title/*"/>
        
        <xsl:choose>
          <xsl:when test="$currentPosition &lt; count($nodes)">
            <xsl:variable name="nextPosition" select="$currentPosition + 1"/>
            <xsl:call-template  name="createBreadcrumbHierarchy">
              <xsl:with-param name="nodes" select="$nodes"/>
              <xsl:with-param name="currentPosition" select="$nextPosition"/>
            </xsl:call-template>
          </xsl:when>
          
          <xsl:otherwise>
            <div class="slideSectionOverview">
              <xsl:apply-templates select="$nodes[$currentPosition]/d:info/d:abstract/d:para"/>
            </div>
          </xsl:otherwise>
        </xsl:choose>       
      </li>
    </ul>
  </xsl:template>  
  
  <xsl:template name="createTooltipBreadcrumbHierarchy">
    <xsl:param name="nodes"/>
    <xsl:param name="currentPosition"/>
    <ul>
      <xsl:if test="$currentPosition = 1">
        <xsl:attribute name="class">tooltiptext</xsl:attribute>
      </xsl:if>
      
      <li style="list-style-type: none;">
        <xsl:if test="not($currentPosition = 1)">
          <xsl:text>➟ </xsl:text>
        </xsl:if>
        
        <xsl:apply-templates select="$nodes[$currentPosition]/d:title/text()|$nodes[$currentPosition]/d:title/*"/>
        
        <xsl:if test="$currentPosition &lt; count($nodes)">
          <xsl:variable name="nextPosition" select="$currentPosition + 1"/>
          <xsl:call-template  name="createTooltipBreadcrumbHierarchy">
            <xsl:with-param name="nodes" select="$nodes"/>
            <xsl:with-param name="currentPosition" select="$nextPosition"/>
          </xsl:call-template>
        </xsl:if>
      </li>
    </ul>
  </xsl:template>  
  
  <xsl:template match="d:chapter | d:section | d:appendix" mode="slideUnit">
    
    <xsl:variable name="slideFileName">
      <xsl:call-template name="slideFilename">
        <xsl:with-param name="slideContainerId" select="@xml:id"/>
      </xsl:call-template>
    </xsl:variable>
    
    <!-- Writing slide series -->    
    <xsl:document href="{$slideFileName}" method="html" encoding="utf-8" indent="yes" doctype-system="none">
      
      <html lang="en">
        <head>
          <title>
            <xsl:value-of select="d:title"/>
          </title>
          <link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />
          <link href="common/css/positioning.css" rel="stylesheet" />
          <link href="reveal.js/css/reveal.css" rel="stylesheet" />
          <link href="reveal.js/css/theme/serif.css" id="theme" rel="stylesheet" />
          
          <!-- Code syntax highlighting -->
          <link href="reveal.js/lib/css/zenburn.css" rel="stylesheet" />
          
          <style>
            /* Tooltip container */
            .tooltip {
            position: relative;
            display: inline-block;
            border-bottom: 1px dotted black; /* If you want dots under the hoverable text */
            }
            
            /* Tooltip text */
            .tooltip .tooltiptext {
            visibility: hidden;
            width: 600px;
            background-color: #555;
            color: #fff;
            padding: 50px;
            border-radius: 6px;
            
            /* Position the tooltip text */
            position: absolute;
            z-index: 1;
            bottom: 110%;
            left: 0%;
            margin-left: -300px;
            
            /* Fade in tooltip */
            opacity: 0;
            transition: opacity 0.3s;
            }
            
            /* Tooltip arrow */
            .tooltip .tooltiptext::after {
            content: "";
            position: absolute;
            top: 100%;
            left: 50%;
            margin-left: -5px;
            border-width: 5px;
            border-style: solid;
            border-color: #555 transparent transparent transparent;
            }
            
            /* Show the tooltip text when you mouse over the tooltip container */
            .tooltip:hover .tooltiptext {
            visibility: visible;
            opacity: 1;
            }
          </style>
          
          <!-- Using free header and footer zones -->
          <style type="text/css">
            .header-left {
            position: absolute;
            top: 0%;
            left: 0%;
            }
            .header-right {
            position: absolute;
            top: 0%;
            right: 0%;
            }
            .footer-center {
            position: absolute;
            bottom: 0%;
            left: 40%;
            }</style>
        </head>
        
        <body>
          <!-- Wrap the entire slide show in a div using the "reveal" class. -->
          <div class="reveal">
            <!-- Wrap all slides in a single "slides" class -->
            
            <xsl:variable name="revealSections" select="
              
              .//d:figure[not (ancestor::d:qandaset)] |
              
              (descendant-or-self::d:chapter|
              descendant-or-self::d:section |
              descendant-or-self::d:appendix) [d:figure[not (ancestor::d:qandaset)]]"/>
            
            <xsl:apply-templates select="$revealSections"
              mode="slideRootHeaders"/>
            
            <div class="slides">
              <xsl:apply-templates select="$revealSections"
                mode="slideRootSections"/>
            </div>
          </div>
          
          <script src="reveal.js/js/reveal.js"></script>
          <script>/*<![CDATA[*/
            
            Reveal.initialize({
            controls: true,
            progress: true,
            history: true,
            center: true,
            width: '70%',
            margin: 0.0,
            
            transition: 'convex', // none/fade/slide/convex/concave/zoom
            
            math: {
            mathjax: 'mathjax/MathJax.js',
            config: 'TeX-AMS-MML_HTMLorMML',  // See http://docs.mathjax.org/en/latest/config-files.html
            },
            // Optional reveal.js plugins
            dependencies: [
            { src: 'reveal.js/lib/js/classList.js', condition: function() { return !document.body.classList; } },
            { src: 'reveal.js/plugin/markdown/marked.js', condition: function() { return !!document.querySelector( '[data-markdown]' ); } },
            { src: 'reveal.js/plugin/markdown/markdown.js', condition: function() { return !!document.querySelector( '[data-markdown]' ); } },
            { src: 'reveal.js/plugin/highlight/highlight.js', async: true, callback: function() { hljs.initHighlightingOnLoad(); } },
            { src: 'reveal.js/plugin/zoom-js/zoom.js', async: true },
            { src: 'reveal.js/plugin/notes/notes.js', async: true },
            { src: 'reveal.js/plugin/math/math.js', async: true }
            ]
            });
            /*]]>*/</script>
          
          <script src="common/jquery/jquery-1.7.2.min.js"></script>
          <script type="text/javascript">  
            
            Reveal.addEventListener( 'slidechanged', function( event ) {
            $.currHeaderId = '#__HEADER_' + event.currentSlide.getAttribute("id");
            $.previusHeaderId = '#__HEADER_' + event.previousSlide.getAttribute("id");
            
            $($.previusHeaderId).attr("style", "display:none;");
            $($.currHeaderId).attr("style", "display:block;");
            
            //$('#myShow').text($.previusHeaderId + ":" + $.currHeaderId);
            } );
            
            Reveal.addEventListener( 'ready', function( event ) {	
            $.currHeaderId = '#__HEADER_' + event.currentSlide.getAttribute("id");	    
            $($.currHeaderId).attr("style", "display:block;");	
            //$('#myShow').text($.currHeaderId);
            } );   
          </script>  
          
        </body>
      </html>
    </xsl:document>
  </xsl:template>
  
  <xsl:template match="d:chapter|d:section|d:appendix" mode="slideRootHeaders">
    <div id="__HEADER_{@xml:id}" style="display: none;">
      
      <div class="header-left" style="z-index: 1000;">
        
          <h3>Overview</h3>
        <!-- 
        <xsl:apply-templates select="d:title"/>
        -->
      </div>
      
      <div class="footer-center" style="z-index: 1000;">
        <xsl:apply-templates mode="footer" select="."/>
      </div>
    </div>    
  </xsl:template>
  
  <xsl:template name="generateFollowupQandasetHeaders">
    
    <xsl:variable name="currentFigureGenerateId" select="generate-id()"/>    
    <xsl:variable name="followupQandasets" 
      select="following::d:qandaset[generate-id(preceding::d:figure[not(ancestor::d:qandaset)][1]) = $currentFigureGenerateId]"/>
    
    <xsl:if test="$followupQandasets">
      
      <div id="__HEADER_{@xml:id}_followupExercise" style="display: none;">
        
        <div class="header-left" style="z-index: 1000;">
          
          <xsl:choose>
            <xsl:when test="1 = count($followupQandasets)">
              <h3>Followup exercise</h3>
            </xsl:when>
            <xsl:otherwise>
              <h3>Followup exercises</h3>
            </xsl:otherwise>
          </xsl:choose>            
        </div>
        
        <div class="footer-center" style="z-index: 1000;">
          <xsl:apply-templates mode="footer" select="."/>
        </div>
         
         <!--
        
        <div class="footer-center" style="z-index: 1000;">
          <xsl:choose>
            <xsl:when test="1 = count($followupQandasets)">
              <p>Related exercise</p>
            </xsl:when>
            <xsl:otherwise>
              <p>Related exercises</p>
            </xsl:otherwise>
          </xsl:choose>  
        </div>
      </div>    
      -->
      </div>
    </xsl:if>   
  </xsl:template>
  
  <xsl:template match="d:figure" mode="slideRootHeaders">
    
    <xsl:variable name="primarySectionId">
      <xsl:apply-templates mode="id_or_generate_id" select="."/>
    </xsl:variable>
    
    <xsl:variable name="currentFigure" as="element()*" select="."/>
        
    <xsl:variable name="figBasename">
      <xsl:call-template name="hdm.get.leftmost.of.separator">
        <xsl:with-param name="path" select="d:mediaobject/d:imageobject/d:imagedata/@fileref"/>
        <xsl:with-param name="separator" select="'.fig.svg'"/>
      </xsl:call-template>
      <xsl:call-template name="hdm.get.leftmost.of.separator">
        <xsl:with-param name="path" select="d:mediaobject/d:imageobject/d:imagedata/@fileref"/>
        <xsl:with-param name="separator" select="'.multi.svg'"/>
      </xsl:call-template>
    </xsl:variable>      
    
    <xsl:variable name="figSet" as="element()*">
      <xsl:if test="0 &lt; string-length($figBasename)">
        <xsl:copy-of select="document(concat($figBasename, '.filenames'), .)/start/file"/>
      </xsl:if>
    </xsl:variable>
    
    <xsl:choose>
      
      <xsl:when test="1 &lt; count($figSet/*)"> <!-- Image series -->
        
          <xsl:for-each select="$figSet/*">
            
            <xsl:variable name="currentAnimationId">
              <xsl:choose>
                
                <xsl:when test="1 = position()">
                  <xsl:value-of select="$primarySectionId"/>
                </xsl:when>
                
                <xsl:otherwise>
                  <xsl:value-of select="concat($primarySectionId, '-', position() - 1)"/>
                </xsl:otherwise>
                
              </xsl:choose>
              
            </xsl:variable>
            
            <div id="__HEADER_{$currentAnimationId}" style="display: none;">
              
              <div class="header-left" style="z-index: 1000;">
                <xsl:apply-templates select="$currentFigure/d:title"/>
              </div>
              
              <div class="footer-center" style="z-index: 1000;">               
                <xsl:apply-templates select="$currentFigure" mode="footer"/>
              </div>
              
            </div>
          </xsl:for-each>
      </xsl:when>
      
      <xsl:otherwise>          <!-- Just a single image or other content -->
        
        <div id="__HEADER_{$primarySectionId}" style="display: none;">
          
          <div class="header-left" style="z-index: 1000;">
            <xsl:apply-templates select="$currentFigure/d:title"/>
          </div>
          
          <div class="footer-center" style="z-index: 1000;">               
            <xsl:apply-templates select="$currentFigure" mode="footer"/>
          </div>
          
        </div>
        
      </xsl:otherwise>             
    </xsl:choose>
    
    <xsl:call-template name="generateFollowupQandasetHeaders"/>
    
  </xsl:template>
  
  <xsl:template match="d:chapter|d:section|d:appendix" mode="slideRootSections">
    
    <section id="{@xml:id}">
      <xsl:call-template name="createBreadcrumbHierarchy">
        
        <xsl:with-param name="nodes" 
          select="
          ancestor-or-self::d:section |
          ancestor-or-self::d:chapter |
          ancestor-or-self::d:appendix"/>
        
        <xsl:with-param name="currentPosition" select="1"/>
        
      </xsl:call-template>
    </section>
    
  </xsl:template>
  
  <xsl:template match="d:figure" mode="slideRootSections">
    
    <xsl:variable name="primarySectionId">
      <xsl:apply-templates mode="id_or_generate_id" select="."/>
    </xsl:variable>
    
    <xsl:variable name="figureTitle" >
      <xsl:apply-templates select="d:title"/>
    </xsl:variable>
    
    <xsl:variable name="baseSupplementDir">
      <xsl:if test="ancestor::*/@xml:base">
        <xsl:call-template name="hdm.get.leftmost.of.separator">
          <xsl:with-param name="path" select="ancestor::*/@xml:base"/>
          <xsl:with-param name="separator" select="'/'"/>
        </xsl:call-template>
        <xsl:text>/</xsl:text>
      </xsl:if>
    </xsl:variable>
    
    <xsl:variable name="figBasename">
      <xsl:call-template name="hdm.get.leftmost.of.separator">
        <xsl:with-param name="path" select="d:mediaobject/d:imageobject/d:imagedata/@fileref"/>
        <xsl:with-param name="separator" select="'.fig.svg'"/>
      </xsl:call-template>
      <xsl:call-template name="hdm.get.leftmost.of.separator">
        <xsl:with-param name="path" select="d:mediaobject/d:imageobject/d:imagedata/@fileref"/>
        <xsl:with-param name="separator" select="'.multi.svg'"/>
      </xsl:call-template>
    </xsl:variable>      
    
    <xsl:variable name="figSet" as="element()*">
      <xsl:if test="0 &lt; string-length($figBasename)">
        <xsl:copy-of select="document(concat($figBasename, '.filenames'), .)/start/file"/>
      </xsl:if>
    </xsl:variable>
    
    <xsl:variable name="currentFigureFooter">
      <xsl:apply-templates select="." mode="footer"/>
    </xsl:variable>
    
    <xsl:choose>
      
      <xsl:when test="1 &lt; count($figSet/*)"> <!-- Image series -->
        <section>
          <xsl:for-each select="$figSet/*">
            <section>
              <xsl:choose>
                
                <xsl:when test="1 = position()">
                  <xsl:attribute name="id" >
                    <xsl:value-of select="$primarySectionId"/>
                  </xsl:attribute>
                </xsl:when>
                
                <xsl:otherwise>
                  <xsl:attribute name="id" >
                    <xsl:value-of select="concat($primarySectionId, '-', position() - 1)"/>
                  </xsl:attribute>
                  
                  <xsl:attribute name="data-transition">none</xsl:attribute>
                </xsl:otherwise>
              </xsl:choose>
                            
              <div class="mediaobject">
                <img width="95%" src="{concat($baseSupplementDir, $figBasename, '-', position() - 1, '.svg')}"  alt="layered SVG image"/>                  
              </div>
                            
            </section>
          </xsl:for-each>
        </section>
      </xsl:when>
      
      <xsl:otherwise>          <!-- Just a single image or other content -->
        
        <section id="{$primarySectionId}">
          
          <xsl:apply-templates select="*[not(self::d:title)]"/>
          
        </section>
        
      </xsl:otherwise>             
    </xsl:choose>
    
    <xsl:call-template name="generateFollowupQandasets"/>
    
  </xsl:template>
  
  <xsl:template match="d:imagedata">
    <xsl:variable name="baseSupplementDir">
      <xsl:if test="ancestor::*/@xml:base">
        <xsl:call-template name="hdm.get.leftmost.of.separator">
          <xsl:with-param name="path" select="ancestor::*/@xml:base"/>
          <xsl:with-param name="separator" select="'/'"/>
        </xsl:call-template>
        <xsl:text>/</xsl:text>
      </xsl:if>
    </xsl:variable>
    
    <img width="95%" src="{concat($baseSupplementDir, @fileref)}"  alt="{ancestor::d:figure/d:title}"/>    
  </xsl:template>
  
  <xsl:template name="generateFollowupQandasets">
    
    <xsl:variable name="currentFigureGenerateId" select="generate-id()"/>    
    <xsl:variable name="followupQandasets" 
      select="following::d:qandaset[generate-id(preceding::d:figure[not(ancestor::d:qandaset)][1]) = $currentFigureGenerateId]"/>
    
    <xsl:if test="$followupQandasets">
      
      <xsl:if test="10 &lt; count($followupQandasets)">
        <xsl:message>
          <xsl:text>Warning: </xsl:text>
          <xsl:value-of select="count($followupQandasets)"/>
          <xsl:text> consecutive followup exercises at slide '</xsl:text>
          <xsl:apply-templates select="d:title"/>
          <xsl:text>', id=</xsl:text>
          <xsl:value-of select="@xml:id"/>
        </xsl:message>
      </xsl:if>
      
      <xsl:variable name="primarySectionId">
        <xsl:apply-templates mode="id_or_generate_id" select="."/>
      </xsl:variable>
      
      <section id="{$primarySectionId}_followupExercise">
        <xsl:choose>
          
          <xsl:when test="1 = count($followupQandasets)">
            <xsl:apply-templates select="$followupQandasets" mode="createTitleLink"/>
          </xsl:when>
          
          <xsl:otherwise>
            <ol>
              <xsl:for-each select="$followupQandasets">
                <li>
                  <xsl:apply-templates select="." mode="createTitleLink"/>
                </li>                
              </xsl:for-each>
            </ol>
          </xsl:otherwise>
          
        </xsl:choose>  
      </section>      
    </xsl:if>
    
  </xsl:template>
    
  <xsl:template match="d:figure" mode="footer"> 
    
    <div class="hdmfooter">              
      <table>
        <tr>
          <td class="tooltip">
            <a target="_blank">
              <xsl:attribute name="href">
                <xsl:call-template name="href.target.uri"/>
              </xsl:attribute>
              <img src="common/images/book.svg" width="60"
                style="border: 0mm; margin-top: 0mm; margin-bottom: 0mm;"></img>
              <p class="tooltiptext">Lecture notes</p>
            </a>
          </td>
          <td class="tooltip">
            <a  target="_blank" href="#{parent::*/@xml:id}">
              <img src="common/images/compass.svg" width="60"
                style="border: 0mm; margin-top: 0mm; margin-bottom: 0mm;"></img>
            </a>
            <xsl:call-template name="createTooltipBreadcrumbHierarchy">
              
              <xsl:with-param name="nodes" 
                select="
                ancestor-or-self::d:section|
                ancestor-or-self::d:chapter|
                ancestor-or-self::d:appendix"/>
              
              <xsl:with-param name="currentPosition" select="1"/>
              
            </xsl:call-template>
          </td>
          <xsl:variable name="qandaId" select="@xml:id"/>
          <xsl:if test="$topicLookup/map/entry[@id = $qandaId]">
            
            <td class="tooltip">
              <a target="_blank" href="https://bb.mi.hdm-stuttgart.de/topic/{$topicLookup/map/entry[@id = $qandaId]/@tid}">
                <img src="common/images/comment.svg"
                  style="border: 0mm; margin-top: 0mm; margin-bottom: 0mm;" width="60" ></img></a>
              <p class="tooltiptext">Create comment</p>
            </td>
          </xsl:if>                    
        </tr>
      </table>
    </div>
  </xsl:template>
  
  <xsl:template match="d:chapter|d:section|d:appendix" mode="footer"> 
    
    <div class="hdmfooter">              
      <table>
        <tr>
          <td class="tooltip">
            <a target="_blank">
              <xsl:attribute name="href">
                <xsl:call-template name="href.target.uri"/>
              </xsl:attribute>
              <img src="common/images/book.svg" width="60"
                style="border: 0mm; margin-top: 0mm; margin-bottom: 0mm;"></img>
              <p class="tooltiptext">Lecture notes</p>
            </a>
          </td>          
        </tr>
      </table>
    </div>
  </xsl:template>
  
  <xsl:template match="d:qandaset" mode="createTitleLink">
    
    <xsl:variable name="linkTarget">
      <xsl:call-template name="href.target.uri"/>
    </xsl:variable>
    
    <xsl:choose>
      <xsl:when test="d:title">
        <xsl:apply-templates select="d:title/node()" mode="createTitleLink">
          <xsl:with-param name="linkTarget" select="$linkTarget"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="preceding-sibling::d:title[1]/node()" mode="createTitleLink">
          <xsl:with-param name="linkTarget" select="$linkTarget"/>
        </xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="d:xref|d:link" mode="createTitleLink">
    <xsl:apply-templates select="."/>
  </xsl:template>
  
  <xsl:template match="*|text()" mode="createTitleLink">
    <xsl:param name="linkTarget"/>
    <a href="{$linkTarget}" target="_blank">
      <xsl:apply-templates select="."/>
    </a>
  </xsl:template>
  
  <!-- Get rid of block object names e.g. "Figure 3.1" -->
  <xsl:template match="d:figure">
    <xsl:apply-templates/>
  </xsl:template>
  
  <!-- Ignore e.g. calloutlist elements inside figure --> 
  <xsl:template match="*[contains(@role, 'slideExclude')]">
    <xsl:message>
      <xsl:text>Excluding &lt;</xsl:text>
      <xsl:value-of select="name(.)"/>
      <xsl:text>&gt; from slides</xsl:text>
    </xsl:message>
  </xsl:template>
  
  <xsl:template match="d:figure/d:title">
    <h3>
      <xsl:apply-templates/>
    </h3>
  </xsl:template>
  
  <!-- Hack: Docbooxsl:tek XSL does not handle @valign in images-->  
  <xsl:template match="d:mediaobject[d:imageobject/d:imagedata[@valign]]">
    <img>
      <xsl:attribute name="src">
        <xsl:if test="ancestor::*/@xml:base">
          <xsl:call-template name="hdm.get.leftmost.of.separator">
            <xsl:with-param name="path" select="ancestor::*/@xml:base"/>
            <xsl:with-param name="separator" select="'/'"/>
          </xsl:call-template>
          <xsl:text>/</xsl:text>
        </xsl:if>
        <xsl:value-of select="d:imageobject/d:imagedata/@fileref"/>
      </xsl:attribute>
      
      <xsl:attribute name="style">
        <xsl:variable name="dbValign" select="d:imageobject/d:imagedata/@valign"/>
        
        <xsl:text>vertical-align: </xsl:text>
        <xsl:choose>
          <xsl:when test="$dbValign = 'top'">text-top</xsl:when>
          <xsl:when test="$dbValign = 'middle'">middle</xsl:when>
          <xsl:when test="$dbValign = 'bottom'">text-bottom</xsl:when>
          <xsl:otherwise>
            <xsl:message>
              <xsl:text>Unknown @valign value: </xsl:text>
              <xsl:value-of select="$dbValign"/>
            </xsl:message>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
    </img>
    
  </xsl:template>
  
  <xsl:template match="d:videodata">
    <video controls="controls" preload="auto" width="50%">
      <xsl:attribute name="title">
        <xsl:value-of select="normalize-space(../../../d:title)"/>
      </xsl:attribute>
      
      <xsl:variable name="hdm_ImageFilename"> <!-- hdm_ prefix: do not mess with docbook! -->
        <xsl:call-template name="mediaobject.filename">
          <xsl:with-param name="object" select=".."/>
        </xsl:call-template>
      </xsl:variable>
      
      <source src="{$hdm_ImageFilename}" type='video/webm' />
      <source src="{$hdm_ImageFilename}.mp4" type='video/mp4'/>
      <xsl:text>Your Browser does not support the video tag</xsl:text>
    </video>
  </xsl:template>
  
  <xsl:template match="*" mode="slideRootSections">
    <p>
      <xsl:text>No template defined for element '</xsl:text>
      <xsl:value-of select="name(.)"/>
      <xsl:text>' in mode 'slideRootSections'.</xsl:text>
    </p>
  </xsl:template>
  
  <xsl:template match="*" mode="slideRootHeaders">
    <xsl:message>
      <xsl:text>No template matching '</xsl:text>
      <xsl:value-of select="name(.)"/>
      <xsl:text>' in mode 'slideRootHeaders'</xsl:text>
    </xsl:message>    
  </xsl:template>
  
  <xsl:template match="*" mode="slideUnit">
    <xsl:message>
      <xsl:text>No template matching '</xsl:text>
      <xsl:value-of select="name(.)"/>
      <xsl:text>' in mode 'slideUnit'</xsl:text>
    </xsl:message>    
  </xsl:template>
  
  <xsl:template match="*" mode="footer">
    <xsl:message>
      <xsl:text>No template defined for element "</xsl:text>
      <xsl:value-of select="name(.)"/>
      <xsl:text>" in mode "footer"</xsl:text>
    </xsl:message>
  </xsl:template>
  
</xsl:stylesheet>
